.. _documentation:

Documentation
=============

This is the main page documenting the *scikit-hep* package, example usage, and the user API.
Please refer to the links on the page about :ref:`affiliated packages <affiliations>` for their documentation.

.. toctree::
    :maxdepth: 2

    api/api.rst
    examples/examples.rst
    faq.rst
    resources.rst

You can also search through the list of modules or the full index:

* :ref:`modindex`
* :ref:`genindex`
